#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-04 12:34
class Api:
    def __init__(self, uri, name=None, serverUrl=None, desc=None):
        self.uri = uri
        self.name = name
        self.serverUrl = serverUrl
        self.desc = desc


import json
from toolbox import ObjectDict


#
# 描述  JSON工具类
# @author dejian.liu
# @date 2022-08-01 10:28
#
class JsonUtil:

    @staticmethod
    def format(self):
        d = {}
        d.update(self.__dict__)
        return d

    @staticmethod
    def toJson(obj):
        return json.dumps(obj, skipkeys=True, ensure_ascii=False, default=JsonUtil.format)

    @staticmethod
    def toObject(json_str):
        json_obj = json.loads(json_str)
        if type(json_obj).__name__ == 'dict':
            return ObjectDict(json_obj)
        return json_obj



#!/usr/bin/python
# -*- coding: UTF-8 -*-
import hashlib
import os
import string
import oss2


# 阿里云bucket
from common.model.Response import Response
from config import settings
from utils.crypto.Md5Util import Md5Util

bucket = oss2.Bucket(oss2.Auth(settings.ALI_OSS_KEY, settings.ALI_OSS_SECRET),
                     settings.ALI_OSS_ENDPOINT, settings.ALI_OSS_BUCKET)


#
# 描述  阿里云OSS工具
# @author dejian.liu
# @date 2022-08-01 10:28
#
class OssUtil:
    # """
    #  从阿里云下载文件
    #  :param oss_key 待下载文件KEY
    #  :param file_dir 指定下载 文件路径，可以为空，为空的话默认下载到当前目录
    # """
    @staticmethod
    def download_file(oss_key, *file_dir):
        download_path = os.getcwd();
        if len(file_dir) > 0:
            download_path = file_dir[0]
            if not os.path.exists(download_path):
                os.makedirs(download_path)

        file_segs = oss_key.split("/");
        file_name = file_segs[len(file_segs) - 1]
        current_file = download_path + "/" + file_name
        result = bucket.get_object_to_file(oss_key, current_file)

        if 200 == result.status:
            return Response.success(current_file)
        else:
            return Response.fail(result.resp)

    # """
    # 删除文件
    # :param oss_key 待删除文件的KEY
    # """

    @staticmethod
    def remove_file(oss_key):
        result = bucket.delete_object(oss_key)
        if 200 == result.status:
            return Response.success()
        else:
            return Response.fail(result.resp)

    # """
    # 文件上传
    # :param file_path 待上传的文件
    # :param oss_key 用户自定义上传KEY
    # """
    @staticmethod
    def upload_file(file_path, oss_key=None):
        if not os.path.exists(file_path) or os.path.isdir(file_path):
            raise Exception("待上传文件:{} 不存在".format(file_path))

        if oss_key is None:
            oss_key = "common/" + Md5Util.get_md5_file(file_path)
        result = bucket.put_object_from_file(oss_key, file_path)

        if 200 == result.status:
            return Response.success(oss_key)
        else:
            return Response.fail(result.resp)



#!/usr/bin/python
# -*- coding: UTF-8 -*-


#
# 描述  通用响应对象
# @author dejian.liu
# @date 2022-08-01 10:28
#
from common import Constant
from utils.json.JsonUtil import JsonUtil
from pydantic import BaseModel


class Response(BaseModel):
    status: int = Constant.HTTP_SUCCESS
    message: str = None
    code: int = Constant.BIZ_SUCCESS
    result: object = None
    """
    :param status 为http状态
    :param msg 响应消息
    :param code 业务编码
    :param data 业务数据
    """

    def __init__(self, status, message):
        self.status = status
        self.message = message
        self.code = None
        self.result = None

    def set_result(self, result):
        self.result = result
        return self

    def set_code(self, code):
        self.code = code
        return self

    def set_status(self, status):
        self.status = status
        return self

    def set_msg(self, msg):
        self.msg = msg
        return self

    def toJson(self):
        return JsonUtil.toJson(self)

    @staticmethod
    def successOk():
        return Response.success(Constant.HTTP_SUCCESS, "ok")

    @staticmethod
    def successData(data):
        return Response.success(Constant.HTTP_SUCCESS, "ok", data)

    @staticmethod
    def success(status, msg, data=None):
        res = Response(status, msg)
        res.set_result(data)
        return res

    @staticmethod
    def fail(status, msg, code=None):
        res = Response(status, msg)
        res.set_code(code)
        return res

    @staticmethod
    def failMsg(msg):
        return Response.fail(Constant.HTTP_ERROR, msg)



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-03 15:34
import json


class Properties(object):
    # '''
    # :param prop_str 为key=value类型的字符串
    # '''
    def __init__(self, prop_str: str):
        self.prop_str = prop_str
        self.prop = dict()
        self.__parse()

    # 解析配置文件
    def __parse(self):
        contents = self.prop_str.splitlines()
        for line in contents:
            try:
                line = line.strip()
                if len(line) == 0:
                    continue
                if line.find("#") != -1:
                    line = line[line.find("#"):len(line)]
                    # print(line)
                    continue
                if line.find('=') > 0:
                    strs = line.split('=')
                    key = strs[0].strip()
                    value = line[len(strs[0]) + 1:].strip()
                    self.prop[key] = value
            except Exception as e:
                print(e)

    # 配置合并
    def add_all(self, dict_prop: dict):
        if type(dict_prop).__name__ == 'dict':
            self.prop = dict(self.prop, **dict_prop)
        elif type(dict_prop).__name__ == 'Properties':
            self.prop = dict(self.prop, **dict_prop.prop)

    def get_value(self, key):
        return self.prop.get(key)

    def remove_prop(self, key):
        self.prop.pop(key)
        return self

    def clear(self):
        self.prop.clear()
        return self

    def get_source_prop(self) -> dict:
        return self.prop



#!/usr/bin/python
# -*- coding: UTF-8 -*-

#
# 描述  MD5加密工具
# @author dejian.liu
# @date 2022-08-01 10:28
#
import hashlib
import os.path


class Md5Util:
    """
    MD5加密文本
    :param word 待加密字符串
    """

    @staticmethod
    def get_md5(word):
        if isinstance(word, str):
            word = word.encode("utf-8")
        else:
            raise Exception("待加密参数必须为字符串")
        m = hashlib.md5()
        m.update(word)
        return m.hexdigest()

    """
    获取文件MD5
    :param file_path 待加密文件
    """

    @staticmethod
    def get_md5_file(file_path):
        if not os.path.exists(file_path) or os.path.isdir(file_path):
            raise Exception("文件{}不存在".format(file_path))
        with open(file_path, 'rb') as f:
            md5obj = hashlib.md5()
            md5obj.update(f.read())
            return md5obj.hexdigest()



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述: 消息消费者
# @author: dejian.liu
# @date:  2022-08-01 17:52
import json


from kafka3 import KafkaConsumer


class MessageConsumer:

    def __init__(self, brokers, topic_name, group_id):
        self.consumer = None
        self.brokers = brokers
        self.topic_name = topic_name
        self.group_id = group_id

    # 获取销毁者
    def get_consumer(self):
        return self.consumer

    # 启动consumer
    def start(self, callback):
        try:
            consumer = KafkaConsumer(self.topic_name,
                                     value_deserializer=json.loads,
                                     group_id=self.group_id,
                                     bootstrap_servers=[self.brokers])
            self.consumer = consumer
            for message in consumer:
                callback(message)
        except KeyboardInterrupt as e:
            print(e)

    # 关闭consumer
    def close(self):
        self.consumer.close(True)

    # 暂停
    def paused(self, *partitions):
        self.consumer.paused(partitions)

    # 恢复
    def resume(self, *partitions):
        self.consumer.resume(partitions)



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述: 枚举集合
# @author: dejian.liu
# @date:  2022-08-02 11:56

from enum import Enum, unique


# 事件数据类型
class DataType(Enum):
    TEXT = 1
    JSON = 2


# 数据应用场景
class DataScene(Enum):
    WORD_COUNT = 1  # 单词统计
    CALC_SUMMARY = 2  # 计算摘要



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-10 14:39

# 阿里云OSS配置
ALI_OSS_KEY = 'xxxxxxxx'
ALI_OSS_SECRET = 'yyyyyyyyyyy'
ALI_OSS_BUCKET = 'backet'
ALI_OSS_ENDPOINT = 'dev.xx.com'

# nacos 统一配置中心
NACOS_SERVER = "http://192.168.0.12:8848"
NACOS_USER_NAME = "nacos"
NACOS_PASSWORD = "nacos"
NACOS_NAMESPACE = "dev"
NACOS_ALG_WEB_GROUP = "DEFAULT_GROUP"
NACOS_ALG_WEB_DATA_ID = "common"
NACOS_SERVER_NAME = "ldj-common"

# xxl-job配置
XXL_JOB_SERVER = "http://192.168.0.123:8080/xxl-job-admin/api/"
XXL_JOB_HOST = "192.168.0.88"
XXL_JOB_EXECUTOR_NAME="liuliu"
XXL_JOB_PORT = 9999
XXL_JOB_TOKEN = ""


#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述: 统一配置/注册中心
# @author: dejian.liu
# @date:  2022-08-03 14:23
import nacos

from config import settings
from utils.prop.Properties import Properties


class NacosClient:
    client: nacos.NacosClient = None
    # dict 字典类型
    prop_dict = dict()

    # 获取nacos客户端
    @staticmethod
    def get_client() -> nacos.NacosClient:
        try:
            if NacosClient.client is None:
                server = settings.NACOS_SERVER
                env = settings.NACOS_NAMESPACE
                NacosClient.client = nacos.NacosClient(server, endpoint=None, namespace=env, ak=None, sk=None,
                                                       username=settings.NACOS_USER_NAME,
                                                       password=settings.NACOS_PASSWORD)

            return NacosClient.client
        except Exception as e:
            print(e)
            raise Exception("获取nacos client 失败:{}".format(e.__cause__))



    @staticmethod
    def get_config(dataId: str, group: str) -> Properties:
        '''
          :param dataId  节点ID
          :param group 分组
          :return kli_alg_platform.common.utils.prop.Properties
          '''
        config_key = group + "_" + dataId
        properties = NacosClient.prop_dict.get(config_key)
        print(properties)
        if properties is None:
            prop_str = NacosClient.get_client().get_config(dataId, group)
            properties = Properties(prop_str)
            NacosClient.prop_dict[config_key] = properties
        return properties

    '''
    :param dataId  节点ID
    :param group 分组
    :param callback 回调函数
    '''

    @staticmethod
    def add_config_watcher(dataId: str, group: str, callback):
        config_key = group + "_" + dataId

        # 定义内部回调函数
        def __config_callback(data):
            print("group:{} data_id:{} config change!".format(data.get("group"), data.get("data_id")))
            prop_str = data["content"]
            new_prop = Properties(prop_str)
            source_prop = NacosClient.get_config(dataId, group)
            source_prop.add_all(new_prop.prop)
            NacosClient.prop_dict[config_key] = source_prop
            callback(source_prop)

        # 增加配置监听
        NacosClient.get_client().add_config_watcher(dataId, group, __config_callback)

    @staticmethod
    def remove_config_watcher(dataId: str, group: str, callback):
        NacosClient.get_client().remove_config_watcher(dataId, group, callback)

    @staticmethod
    def register_service(service_ip, port, service_name, namespaceId, namespace, group):
        NacosClient.get_client().register



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述: feign 客户端
# @author: dejian.liu
# @date:  2022-08-04 9:55
import os
import sys

from support.feign.Api import Api

apis = dict()


# '''
# @FeignClient 注解
# '''
def FeignClient(meta: Api):
    def decorator(func):
        func.__annotations__["meta"] = meta
        return func

    return decorator


# '''
# 注册restAPI接口
# '''
def register(func):
    if func is None:
        return
    meta_api: Api = func.__annotations__.get("meta")
    if meta_api is None:
        return
    apis[meta_api.uri] = meta_api


@FeignClient(meta=Api(uri="api/nlp/summary", name="计算摘要", serverUrl="http://127.0.0.1:8000"))
def summary(param):
    print("test===" + param)
    return param + " good"


def parse_anno(fun):
    meta: Api = fun.__annotations__.get("meta")
    if meta is None:
        print("========meta is null=============")
    else:
        print(meta.uri)


import importlib

if __name__ == "__main__":
    # summary("vaudevillian")
    # module = sys.modules[__name__]
    # sum = getattr(module, 'summary')
    # print(sum)
    # parse_anno(sum)
    modules = sys.modules
    print("===========================")
    for mod in modules:
        print(mod)
    print("----------------------")
    print(sys.modules["Api"])



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述: 消息生产者
# @author: dejian.liu
# @date:  2022-08-01 21:41
import json

from kafka3 import KafkaProducer
from kafka3.errors import KafkaError

from utils.json.JsonUtil import JsonUtil


class MessageProducer:

    # '''
    # :param broker_servers kafka服务地址
    # :param topic_name 队列名称
    # :param key 消息发送的KEY,消息paration 路由使用
    # '''
    def __init__(self, broker_servers, topic_name, key=None):
        self.broker_servers = broker_servers
        self.topic_name = topic_name
        self.key = key
        self.producer = None
        self.producer = KafkaProducer(bootstrap_servers=broker_servers)

    # '''
    # 关闭producer
    # '''
    def close(self):
        try:
            self.producer.close()
        except KafkaError as e:
            print(e)

    # '''
    # 发送消息
    # :param data 待发送的消息体
    # '''
    def sendMessage(self, data):
        try:
            send_message = json.dumps(data, ensure_ascii=True, default=JsonUtil.format)
            producer = self.producer
            v = send_message.encode('utf-8')
            if self.key is None:
                self.key = "1"
            k = self.key.encode('utf-8')
            # print("send msg:(k,v)", k, v)
            future = producer.send(self.topic_name, key=k, value=v)
            producer.flush()
            return future
        except KafkaError as e:
            print(e)



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-05 14:31
from functools import wraps


class D(object):
    def __init__(self, before=None, after=None):
        self.before = before
        self.after = after

    def __call__(self, func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            middle_result = kwargs.copy()
            beforeResult = self.before(args, middle_result)
            print(beforeResult)
            middle_result["name1"] = "liudejian"
            result = func(*args, **kwargs)
            if self.after is not None:
                self.after(*args, **middle_result)
            print("在函数执行后，做一些操作")
            return result

        return wrapper


def beforeF(*args, **kwargs):
    print("========before======={},{}".format(args, kwargs))
    return "liudejian"


def afterF(*args, **kwargs):
    print(kwargs)
    print("=====after====={}={}".format(args,kwargs))
    return "after111"


@D(before=beforeF, after=afterF)
def query(name, age):
    print('函数执行中。。。')
    return "我是 {}, 今年{}岁 ".format(name, age)


print(query('Amos', 24))



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述: 请求对象
# @author: dejian.liu
# @date:  2022-08-10 15:19
from pydantic import BaseModel


class Request(BaseModel):
    body: object = None
    start: int = 0
    limit: int = 10
    params: dict = None

    @staticmethod
    def build(body: object, start: int, limit: int):
        req = Request()
        req.body = body
        req.start = start
        req.limit = limit
        return req



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-08 10:57
import threading


class ThreadLocal:
    box = {}

    def __setattr__(self, key, value):
        thread_id = threading.get_ident()
        # 单元格已存在
        if thread_id in ThreadLocal.box:
            ThreadLocal.box[thread_id][key] = value
        else:
            ThreadLocal.box[thread_id] = {key: value}

    def __getattr__(self, item):
        thread_id = threading.get_ident()
        return ThreadLocal.box[thread_id][item]

    def remove(self):
        thread_id = threading.get_ident()
        del ThreadLocal.box[thread_id]




#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-02 10:26
from pydantic import BaseModel


class Event(BaseModel):
    dataType: int = None
    dataSence: int = None
    content: str = None

    # '''
    # :param dataType 1=text  2= json
    # :param dataSence 1=word_count
    # :param content 事件内容
    # '''
    def __init__(self, dataType, dataSence, content):
        self.dataType = dataType
        self.dataSence = dataSence
        self.content = content

    @staticmethod
    def build(dataType, dataSence, content):
        return Event(dataType, dataSence, content)



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述: AOP 面向切面编程
# @author: dejian.liu
# @date:  2022-08-05 13:50

from functools import wraps

'''
aop对象
'''


class Aop(object):
    # 构造方法
    def __init__(self, before=None,
                 after=None,
                 exception=None,
                 final=None):
        self.before = before
        self.after = after
        self.exception = exception
        self.final = final

    # 调用函数时触发
    def __call__(self, func):
        @wraps(func)
        def wrapper(*args, **kwargs):
            func_result = None
            # 拦截执行的中间结果
            middle_kwargs = kwargs.copy()
            if self.before is not None:
                result = self.before(*args, **kwargs)
                if result is not None:
                    middle_kwargs["before_result"] = result
            try:
                func_result = func(*args, **kwargs)
                if self.after is not None:
                    result = self.after(*args, **middle_kwargs)
                    if result is not None:
                        middle_kwargs["after_result"] = result
            except Exception as e:
                if self.exception is not None:
                    result = self.exception(*args, **middle_kwargs)
                    if result is not None:
                        middle_kwargs["exception_result"] = result
                print(e)
            finally:
                if self.final is not None:
                    result = self.final(*args, **middle_kwargs)
                    if result is not None:
                        middle_kwargs["final_result"] = result
            return func_result

        return wrapper



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-04 10:14

class ClassMeta:
    '''
    :param uri 请求接口的相对路径[必填]
    :param name 服务名称[可选]
    :param serverUrl 服务基础地址 (example:http(s)://localhost:8080)[可选]
    :param desc 服务描述[可选]
    '''
    def __init__(self, uri, name=None, serverUrl=None, desc=None):
        self.uri = uri
        self.name = name
        self.serverUrl = serverUrl
        self.desc = desc



#!/usr/bin/python
# -*- coding: UTF-8 -*-
# 描述:
# @author: dejian.liu
# @date:  2022-08-10 14:02
from setuptools import setup, find_packages

setup(
    name="ldj-common",
    version="0.0.3",
    author="ldj",
    author_email="zuiwoxing@qq.com",
    description="LDJ公共库(aop/crypto/json/nacos/oss/kafka)",
    long_description_content_type="text/markdown",
    url="https://www.messagesea.com/",
    packages= find_packages(),
    classifiers=[
        # 发展时期,常见的如下
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',
        # 开发的目标用户
        'Intended Audience :: Developers',
        # 属于什么类型
        'Topic :: Software Development :: Build Tools',
        # 许可证信息
        'License :: OSI Approved :: MIT License',
        # 目标 Python 版本
        'Programming Language :: Python :: 3.8',
    ],
)
